==> gatsby-core-theme-30.0.80.tgz: package/src/helpers/tracker.test.js <==
import * as Tracker from './tracker.mjs';

describe('Tracker Helper', () => {
  const operator = {
    short_name: 'rizk',
    type: 'sportsbook',
    market: 'ie_en',
    links: {
      main: 'testing main link',
      ppc: 'testing ppc link',
      christmas: 'testing christmas links',
    },
  };

  test('getTrackerName main/default link', () => {
    const trackerObj = Tracker.getTrackerName(operator, 'default', '/no/visit/rizk');
    expect(trackerObj.name).toEqual('main');
    expect(trackerObj.value).toEqual('testing main link');
  });

  test('getTrackerName non main/default link', () => {
    const trackerObj = Tracker.getTrackerName(operator, 'default', '/no/visit/rizk/sportsbook/ppc');
    expect(trackerObj.name).toEqual('ppc');
    expect(trackerObj.value).toEqual('testing ppc link');
  });

  test('getTrackerName non main/default link with slash', () => {
    const trackerObj = Tracker.getTrackerName(
      operator,
      'default',
      '/no/visit/rizk/sportsbook/ppc/'
    );
    expect(trackerObj.name).toEqual('ppc');
    expect(trackerObj.value).toEqual('testing ppc link');
  });

  test('getTrackerName non existent main/default link', () => {
    const trackerObj = Tracker.getTrackerName(
      operator,
      'default',
      '/no/visit/rizk/sportsbook/ppc3'
    );
    expect(trackerObj.name).toEqual('main');
    expect(trackerObj.value).toEqual('testing main link');
  });

  global.fetch = jest.fn(() =>
    Promise.resolve({
      json: () => Promise.resolve({ success: true }),
    })
  );
  beforeEach(() => {
    fetch.mockClear();
  });

  test('getAffiliateLink url params', async () => {
    await Tracker.getAffiliateLink(operator, '/no/visit/rizk', { template: 'default' }, null);

    const tracker = Tracker.getTrackerName(operator, 'default', '/no/visit/rizk');

    const urlParam = {
      site_id: process.env.SITE_ID,
      operator_short_name: operator.short_name,
      operator_type: operator.type,
      language: operator.market.split('_')[1],
      tracker_name: tracker.name,
      market_short_code: operator.market,
      ip_address: '127.0.0.1',
    };

    expect(fetch).toBeCalledTimes(1);
    expect(fetch).toBeCalledWith(
      `${process.env.GATSBY_TRACKING_API_URL}?${new URLSearchParams(
        urlParam
      ).toString()}&user_agent=null&user_uuid=null&facebook_browser_id=null&facebook_click_id=null&facebook_pixel_id=null`
    );
  });

  test('getAffiliateLink url params extras', async () => {
    await Tracker.getAffiliateLink(
      operator,
      '/no/visit/rizk',
      { template: 'default' },
      null,
      '/path?extraparam=val&extraparam2=val2'
    );

    expect(fetch).toBeCalledTimes(1);
    expect(fetch).toBeCalledWith(
      `testlink?site_id=82&operator_short_name=rizk&operator_type=sportsbook&language=en&tracker_name=main&market_short_code=ie_en&ip_address=127.0.0.1&user_agent=null&user_uuid=null&facebook_browser_id=null&facebook_click_id=null&facebook_pixel_id=null&extraparam=val&extraparam2=val2`
    );
  });

  test('getTrackingAPIParams tests', async () => {
    const params = Tracker.getTrackingAPIParams(
      'temlateValue',
      'moduleValue',
      'trackerValue',
      'clickedElementValue',
      'urlValue'
    );
    expect(params.page_type).toEqual('temlateValue');
    expect(params.module).toEqual('moduleValue');
    expect(params.tracker_name).toEqual('trackerValue');
    expect(params.clicked_element).toEqual('clickedElementValue');
    expect(params.request_url).toEqual('urlValue');
  });

  test('getTrackingAPIParams tests with url Params', async () => {
    const params = Tracker.getTrackingAPIParams(
      null,
      null,
      null,
      null,
      'urlValue?fbclid=param1&msclkid=param2&gclid=param3'
    );
    expect(params.request_url).toEqual('urlValue');
    // expect(params.facebook_click_id).toEqual('param1');
    expect(params.microsoft_click_id).toEqual('param2');
    expect(params.google_click_id).toEqual('param3');
  });
});

==> gatsby-core-theme-30.1.3.tgz: package/src/helpers/tracker.test.js <==
import * as Tracker from './tracker.mjs';

describe('Tracker Helper', () => {
  const operator = {
    short_name: 'rizk',
    type: 'sportsbook',
    market: 'ie_en',
    links: {
      main: 'testing main link',
      ppc: 'testing ppc link',
      christmas: 'testing christmas links',
    },
  };

  test('getTrackerName main/default link', () => {
    const trackerObj = Tracker.getTrackerName(operator, 'default', '/no/visit/rizk');
    expect(trackerObj.name).toEqual('main');
    expect(trackerObj.value).toEqual('testing main link');
  });

  test('getTrackerName non main/default link', () => {
    const trackerObj = Tracker.getTrackerName(operator, 'default', '/no/visit/rizk/sportsbook/ppc');
    expect(trackerObj.name).toEqual('ppc');
    expect(trackerObj.value).toEqual('testing ppc link');
  });

  test('getTrackerName non main/default link with slash', () => {
    const trackerObj = Tracker.getTrackerName(
      operator,
      'default',
      '/no/visit/rizk/sportsbook/ppc/'
    );
    expect(trackerObj.name).toEqual('ppc');
    expect(trackerObj.value).toEqual('testing ppc link');
  });

  test('getTrackerName non existent main/default link', () => {
    const trackerObj = Tracker.getTrackerName(
      operator,
      'default',
      '/no/visit/rizk/sportsbook/ppc3'
    );
    expect(trackerObj.name).toEqual('main');
    expect(trackerObj.value).toEqual('testing main link');
  });

  global.fetch = jest.fn(() =>
    Promise.resolve({
      json: () => Promise.resolve({ success: true }),
    })
  );
  beforeEach(() => {
    fetch.mockClear();
  });

  test('getAffiliateLink url params', async () => {
    await Tracker.getAffiliateLink(operator, '/no/visit/rizk', { template: 'default' }, null);

    const tracker = Tracker.getTrackerName(operator, 'default', '/no/visit/rizk');

    const urlParam = {
      site_id: process.env.SITE_ID,
      operator_short_name: operator.short_name,
      operator_type: operator.type,
      language: operator.market.split('_')[1],
      tracker_name: tracker.name,
      market_short_code: operator.market,
      ip_address: '127.0.0.1',
    };

    expect(fetch).toBeCalledTimes(1);
    expect(fetch).toBeCalledWith(
      `${process.env.GATSBY_TRACKING_API_URL}?${new URLSearchParams(urlParam).toString()}`
    );
  });

  test('getAffiliateLink url params extras', async () => {
    await Tracker.getAffiliateLink(
      operator,
      '/no/visit/rizk',
      { template: 'default' },
      null,
      '/path?extraparam=val&extraparam2=val2'
    );

    expect(fetch).toBeCalledTimes(1);
    expect(fetch).toBeCalledWith(
      `testlink?site_id=82&operator_short_name=rizk&operator_type=sportsbook&language=en&tracker_name=main&market_short_code=ie_en&ip_address=127.0.0.1&extraparam=val&extraparam2=val2`
    );
  });

  test('getTrackingAPIParams tests', async () => {
    const params = Tracker.getTrackingAPIParams(
      'temlateValue',
      'moduleValue',
      'trackerValue',
      'clickedElementValue',
      'urlValue'
    );
    expect(params.page_type).toEqual('temlateValue');
    expect(params.module).toEqual('moduleValue');
    expect(params.tracker_name).toEqual('trackerValue');
    expect(params.clicked_element).toEqual('clickedElementValue');
    expect(params.request_url).toEqual('urlValue');
  });

  test('getTrackingAPIParams tests with url Params', async () => {
    const params = Tracker.getTrackingAPIParams(
      null,
      null,
      null,
      null,
      'urlValue?fbclid=param1&msclkid=param2&gclid=param3'
    );
    expect(params.request_url).toEqual('urlValue');
    // expect(params.facebook_click_id).toEqual('param1');
    expect(params.microsoft_click_id).toEqual('param2');
    expect(params.google_click_id).toEqual('param3');
  });
});
